Mysticism Genre ebooks | Global Grey
Description: Download free Mysticism ebooks: pdf, epub and Kindle ebooks about a constellation of distinctive practices, discourses, texts, institutions, traditions...

Download free public domain ebooks: pdfs, epubs and ebooks for Kindle

Download free ebooks about Mysticism, a constellation of distinctive practices, discourses, texts, institutions, traditions, and experiences aimed at human transformation. Available in pdf, epub and Kindle formats. Related categories: Christianity and Gnosticism And Hermetica.

Ancient And Modern Initiation

Available in pdf, epub and kindle ebook formats

Hidden secrets within the life of Christ and the Christian religion, revealed by Max Heindel, as he gives a mystical insight into the alchemical process of the initiation of man. Chapters include The Atlantean Mystery Temple, East Room Of...

Christian Healing: The Science Of Being

Available in pdf, epub and kindle ebook formats

Charles Fillmore teaches you how to heal yourself in this New Thought classic. He writes about the power of thought and words, of prayer, praise, faith and imagination. And of course, love. Each chapter ends with some affirmations, or...

Christian Mysticism

Available in pdf, epub and kindle ebook formats

This book consists of eight lectures, given at the University of Oxford by William Inge, as part of the Bampton Lectures. It begins with an extract from the last will and testament of the late John Bampton and then goes on to the lectures...

Dialogues on the Supersensual Life

Available in pdf, epub and kindle ebook formats

Taken from the Preface: "Man has a spark of the Light and Spirit of God, as a supernatural gift of God given into the birth of his Soul to bring forth by degrees a new birth of that life which was lost in Paradise. This holy spark of the Divine Nature...

Dynamic Thought

Available in pdf, epub and kindle ebook formats

The essence of Hamblin's mystical experience and philosophy was of the omnipresence, omnipotence and all-goodness of God. He believed that abounding health, sufficiency of supply, achievement, accomplishment and joy indescribable are...

Esoteric Christianity

Available in pdf, epub and kindle ebook formats

From the Foreword; 'The object of this book is to suggest certain lines of thought as to the deep truths underlying Christianity, truths generally overlooked, and only too often denied'. Chapters include the Hidden Side Of Christianity...

Freher's Process in the Philosophical Work

Available in pdf, epub and kindle ebook formats

Dionysius Andreas Freher wrote an extended commentary, in many manuscript volumes and amounting to thousands of pages, on the writings and mystical ideas of Jacob Boehme. Boehme's mysticism incorporated a number of alchemical ideas...

Gleanings Of A Mystic

Available in pdf format

A series of essays on practical mysticism. The contents of this book are among the last writings of Max Heindel, the mystic. They contain some of his deepest thoughts and are the result of years of research and occult investigation. Found...

Hindu Mysticism

Available in pdf, epub and kindle ebook formats

This small book gives a brief general outline of some of the most important types of mysticism as well as a systematic introduction to Hindu mysticism as it evolved in India throughout the ages. According to the author, mysticism means a spiritual...

Jesus Christ Heals

Available in pdf, epub and kindle ebook formats

Chapters include: Be Thou Made Whole; God Presence; Realization Precedes Manifestation; Producing Results; The Omnipotence Of Prayer; God Said, And It Was So; Indispensable Assurance; The Fullness Of Time; Healing Through Praise And Thanksgiving...

Jewish Mysticism

Available in pdf, epub and kindle ebook formats

Although the Kabbalah has lately become 'trendy,' there is a dearth of well-written, scholarly books which give a larger perspective on the subject of Jewish Mysticism. In addition, many of the books on the subject are by Occultists, and however...

Lessons in Truth

Available in pdf, epub and kindle ebook formats

A short book about the positive aspects of spirituality. Cady simplifies metaphysics and practical Christianity from the perspective of her personal experiences. Published by the Unity Church movement...

Letters of Myrtle Fillmore

Available in pdf, epub and kindle ebook formats

Chapters include; Jesus Christ; Prayer; Drawing On The Source; Going Into The Silence; Quickened By The Spirit; Understanding The Body; Day And Night Experience; No Incurable Disease; Permanent Prosperity; The Subconsciousness; Threefold...

Mysteries Of Genesis

Available in pdf, epub and kindle ebook formats

Fillmore takes us through Genesis, step by step. Chapters include; Spiritual Man; Manifest Man; The Fall Of Man; The Reaction To Sense Living; The Initial Step Toward Redemption; The Promise Of Salvation; The Fruits Of Faith; The Mental Supplants The...

Mystic Christianity

Available in pdf, epub and kindle ebook formats

Chapters include: The Coming of the Master; The Mystery of the Virgin Birth; The Mystic Youth of Jesus; The Beginning of the Ministry; The Foundation of the Work; The Work of Organization; The Beginning of the End; The End of the Life Work; The Inner...

Mysticism in English Literature

Available in pdf format

This book covers mystical writers, such as Plato and Plotinus, Love and Beauty mystics, such as Shelley and Keats, religious mystics and philosophical mystics...

Mystics Of The Renaissance

Available in pdf, epub and kindle ebook formats

In "Mystics of the Renaissance," Rudolf Steiner examines the thought of eleven European mystics (Eckhart, Tauler, Suso, Ruysbroek, Nicholas of Cusa, Agrippa von Nettesheim, Paracelsus, Weigel, Boehme, Giordano Bruno, and Angelus Silesius) through...

Nature Mysticism

Available in pdf, epub and kindle ebook formats

If you're the sort of person who has no use for traditional spiritual systems of any sort and hope that somehow, someday, you can find spiritual meaning in the natural world around you, this book is for you. Mercer understood very well that the essential...

Of the Imitation of Christ

Available in pdf format

The Imitation of Christ is a Christian devotional book. It was first composed in Latin. It is a handbook for spiritual life arising from the Devotio Moderna movement, where Kempis was a member. The Imitation is perhaps the most widely read devotional...

Practical Mysticism

Available in pdf, epub and kindle ebook formats

This short work is an attempt to show that all humans, even the non-religious ones, have an innate spirituality within them. Written in an almost poetic style, Practical Mysticism cuts to the core of mysticism and teaches you how to get involved with...

Prosperity

Available in pdf, epub and kindle ebook formats

Way before the Law of Attraction became a popular phrase, Charles Fillmore was teaching and writing about prosperity through the creative power of thought. This book is a classic in that it's well-written, easy-to-understand, and very effective in conveying...

Saint Martin The French Mystic

Available in pdf format

Saint Martin The French Mystic and the story of modern Martinism, was first published in 1922. It traces the lineage of St. Martin from his youth to his traditional religious life and his conversion to mysticism and how Martinism was started...

Strange Houses of Sleep

Available in pdf format

This is Waite's most important poetical work, containing 'The Hidden Sacrament of the Holy Graal' which was written in collorabation with Arthur Machen. This edition was limited to 250 copies, of which this is number 15, and it's also signed by...

Studies of English Mystics

Available in pdf format

Taken from a series of lectures delivered in the church of St Margaret's, Westminster, 1905. Chapters include; On the Psychology of Mysticism; The Ancren Riwle and Julian of Norwich; Walter Hylton; William Law; The Mysticism of Wordsworth...

Talks On Truth

Available in pdf, epub and kindle ebook formats

14 Lessons and a question chapter at the end. Lesson subjects include; Reform Your God Thought; Microorganisms; The I Am In Its Kingdom; How Shall The Dead Be Raised?; The Development Of Divine Love; The Ministry Of The Word; Ye Must...

Teach Us To Pray

Available in pdf, epub and kindle ebook formats

In this relatively short book, Charles Fillmore takes us through the various ways in which we can pray and get close to God, with a healthy dose of New Thought. Chapters include, True Prayer; Intellectual Silence And Spiritual Silence; How To Handle...

Teachings Of An Initiate

Available in pdf, epub and kindle ebook formats

This volume of the writings of Max Heindel is a series of messages he sent out through monthly lessons to his students. Chapters include; What Is Spiritual Work?; The Days Of Noah And Of Christ; Mystic Light On The World War ; The Lesson Of Easter...

The Adornment of the Spiritual Marriage

Available in pdf, epub and kindle ebook formats

Jan van Ruysbroeck was a Flemish mystic. He led a life of asuterity, eventually founding a congregation in Groenendaal. His writings were widely circulated in his lifetime and he influenced an entire generation of Christian mystics. He was beatified...

The Candle of Vision

Available in pdf, epub and kindle ebook formats

A set of transcendent essays on Celtic mysticism, describing Russells' luminous excursions into the otherworld, including clairvoyant and prophetic visions, precognition of Gnostic concepts, past-life and astral journeys, and, always, heightened...

The Cloud of Unknowing

Available in pdf, epub and kindle ebook formats

This is Evelyn Underhill's translation of the medieval spiritual guidebook called The Cloud of Unknowing, written by an anonymous English monk. At the core is a mystical approach to Christian prayer, in which God is found not through rote knowledge...

The Cloud Upon the Sanctuary

Available in pdf, epub and kindle ebook formats

Karl von Eckhartshausen was an 18th century German mystic who wrote extensively on esoteric topics. This work, The Cloud Upon the Sanctuary, is Christian mysticism veiled in hermetic code. Eckhartshausen was briefly a member of the Bavarian...

The Confessions of Jacob Boehme

Available in pdf, epub and kindle ebook formats

Jacob Boehme was a German Christian mystic, who, despite humble origins, wrote encyclopedic works detailing a visionary universe, densely inhabited by spirits. Like many other mystics, Boehme saw dualities and trinities everywhere. He believed...

The Epistles of Jacob Boehme

Available in pdf, epub and kindle ebook formats

From the title page: 'Very useful and necessary for those that read his Writings, and are very full of excellent and plaine Instructions how to attaine to The Life of CHRIST'...

The Garden of Eden

Available in pdf, epub and kindle ebook formats

This pamphlet is a version of a lecture which Victoria Claflin Woodhull gave numerous times on the subject of the Garden Of Eden, which she felt was an intricate symbol of the human body, rather than an actual historical location. While a few...

The Goal of Life

Available in pdf, epub and kindle ebook formats

This book is Butler's description of the entire spiritual evolution of humanity. Based on a mystical vision of Christianity, Butler thought that an invisible 'Order of Melchisedek,' 288,000 strong (144,000 male-female couples) would eventually...

The Hidden Church Of The Holy Graal

Available in pdf format

A. E. Waite gets to the core of the Grail legend, an interwoven mass of narratives which started with seeds of pagan folklore and grew into a massive allegorical Christian epic. This 700 page book will satisfy both the academic reader who wants a...

The Mystic Life

Available in pdf format

From the Preface: 'THE Teachings of The Order of Christian Mystics (also known as The Order of the Fifteen), of which the following pages form a part, have been issued privately to students each month continuously since 1908. In view of their...

The Red Book

Available in pdf, epub and kindle ebook formats

'The Red Book' is a primary text in Martinism, a philosophical movement started in 18th century France by Louis-Claude de Saint-Martin and based on Mystic Christian illuminist philosophy with theurgical integration added for good measure...

The Revolution of the Dialectic

Available in pdf, epub and kindle ebook formats

The Revolution of the Dialectic, Practical Methods for Intense Spiritual Transformation, is a book that gives details about how we can resist the evils of this world and turn to higher goals...

The Signature of All Things

Available in pdf, epub and kindle ebook formats

Boehme discourses at length here on one of the fundamental laws of Magic: the law of signatures, the concept that every object in the real world has some hidden meaning, and particularly how these signatures interact. At the core of Boehme's...

The Spiritual Guide

Available in pdf format

Miguel de Molinos was a Spanish mystic, the chief representative of the religious revival known as Quietism. In 1675, Molinos published his most famous work, the Spiritual Guide, which eventually led to him being imprisoned for life by...

The Theory and Practice of Mysticism

Available in pdf format

Chapters include; The Longing for God and Its Implications; The Way Toward God; The Meeting Point; St. Francis of Assisi, Heinrich Suso and Mother Julian of Norwich; Modern Mysticism; and, Practical Mysticism...

The Voice of Isis

Available in pdf format

Written by some unknown teacher of the Order of Christian Mystics, the chapters of this book include; Life's Duties; The Cycle of Fulfillment; Degrees and Orders; The Wisdom Religion; Concerning the Doctrine of Hell Fire; The Eleventh Commandment...

The Wandering Host

Available in pdf, epub and kindle ebook formats

This is an allegorical tale about the search for spiritual meaning...

The Way of Power: Studies in the Occult

Available in pdf, epub and kindle ebook formats

A study of the occult, taking you through various ways and means of achieving stillness and peace. The author is very fond of Indian teachings and a lot of the book reflects this...